@@ -14,7 +14,7 @@ seedfill <- function(z, x=1, y=1, fcol=0, bcol=1, tol=1e-6) {
   ## with cells which have already the fill color
   ## fix: we fill with a color not contained within z
   ffcol <- .Machine$double.xmax
-  z <-.C("seedfill",
+  z <-.C(c_seedfill,
          as.integer(n),
          as.integer(m),
          as.integer(x-1),
